<!doctype style-sheet PUBLIC "-//James Clark//DTD DSSSL Style Sheet//EN">

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Style sheet for slide shows (RTF version)
;; Jon Bosak 1997.08.24
;;   Note that this version assumes 8.5 x 11 inch paper (US and Canada)
;;   and assumes that Word for Windows will be used for printouts
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(declare-characteristic page-number-restart?
   "UNREGISTERED::James Clark//Characteristic::page-number-restart?" #f)

;; put something in this if the document is to be labeled confidential,
;;   for example:
;; (define %confidential-string% "CONFIDENTIAL")

(define %confidential-string% "")

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; layout parameters
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(define %body-font-family% "Times New Roman")
(define %hf-font-family% "Arial")
(define %mono-font-family% "Courier New")
(define %bf-size% 24pt)
(define %hf-size% 12pt)
(define %line-spacing-factor% 1.2)
(define %bf-line-spacing% (* %bf-size% %line-spacing-factor%))
(define %hf-line-spacing% (* %hf-size% %line-spacing-factor%))
(define %title-size-factor% 1.6)
(define %subtitle-size-factor% (/ 4 3 ))
(define %slidehead-size-factor% 1.5)
(define %ss-size-factor% 0.9)
(define %ss-shift-factor% 0.2)

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; overall style
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(define page-style
  (style
   page-width: 8.5in
   page-height: 11in
   left-margin: 6pica
   right-margin: 6pica
   top-margin: 6pica
   bottom-margin: 6pica
   header-margin: 3pica
   footer-margin: 3.5pica
   font-family-name: %body-font-family%
   font-size: %bf-size%
   line-spacing: %bf-line-spacing%))

(define headerfooter-style
  (style
   font-size: %hf-size%
   font-family-name: %hf-font-family%
   line-spacing: %hf-line-spacing%))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; big pieces
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(element SLIDESHOW (process-children))

(element SHOWTITLESLIDE
 (let ((page-footer-confidential
	(make sequence
	      use: headerfooter-style
	      (literal %confidential-string%))))
   (make simple-page-sequence
	 page-number-restart?: #t
	 use: page-style
	 center-footer: page-footer-confidential
	 input-whitespace-treatment: 'collapse
	 quadding: 'start
	 (process-children)
	 (TOC-RULE)
	 (with-mode showtoc
		    (sosofo-append
		     (process-node-list
		      (select-elements
		       (descendants (ancestor "SLIDESHOW"))
		       "MODULETITLESLIDE"))))
	 (TOC-RULE))))

(mode showtoc
      (element MODULETITLESLIDE (process-children))
      (element TITLE (process-children))
      (element (MODULETITLESLIDE TITLE LINE)
	       (make paragraph
		     font-size: (/ %bf-size% 2)
		     line-spacing: (/ %bf-line-spacing% 2)
		     start-indent: 4pica
		     first-line-start-indent: -2pica
		     (process-children)
		     (make leader (literal "."))
		     (literal
		      (string-append
		       (format-number
			(ancestor-child-number "SLIDEMODULE") "A")
		       "-"))
		     (current-node-page-number-sosofo))))

(define (TOC-RULE)
  (make rule
	orientation: 'horizontal
	space-before: 2pica
	space-after: 2pica
	line-thickness: 1pt
	length: 37pica
	start-indent: 2pica
	display-alignment: 'start))

;; don't display showhead in sequence
(element SHOWHEAD (empty-sosofo))

(mode hf-mode
  (element SHOWHEAD
	   (process-children))
  (element MODHEAD
	   (process-children)))

(element SLIDEMODULE
 (let ((page-footer-confidential
	(make sequence
	      use: headerfooter-style
	      (literal %confidential-string%)))
       (page-footer-pagenumber
	(make sequence
	      use: headerfooter-style
	      (literal
	       (string-append
		"Page "
		(format-number (element-number) "A")
		"-"))
	      (page-number-sosofo)))
       (page-header
	(make sequence
	      use: headerfooter-style
	      (with-mode hf-mode (process-first-descendant "MODHEAD")))))
   (if (equal? "" %confidential-string%)
       (make simple-page-sequence
	     page-number-restart?: #t
	     use: page-style
	     center-header: page-header
	     center-footer: page-footer-pagenumber
	     input-whitespace-treatment: 'collapse
	     quadding: 'start
	     (process-children))
     (make simple-page-sequence
	   page-number-restart?: #t
	   use: page-style
	   center-header: page-header
	   left-footer: page-footer-confidential
	   right-footer: page-footer-pagenumber
	   input-whitespace-treatment: 'collapse
	   quadding: 'start
	   (process-children)))))

;; don't display modhead in sequence
(element MODHEAD (empty-sosofo))

(element MODULETITLESLIDE
  (make display-group
 	(process-children)
	(TOC-RULE)
	(with-mode moduletoc
		   (sosofo-append
		    (process-node-list
		     (select-elements
		      (descendants (ancestor "SLIDEMODULE")) "SLIDEHEAD"))))
	(TOC-RULE)))

(mode moduletoc
      (element SLIDEHEAD
	       (make paragraph
		     font-size: (/ %bf-size% 2)
		     line-spacing: (/ %bf-line-spacing% 2)
		     start-indent: 4pica
		     first-line-start-indent: -2pica
		     (process-children)
		     (make leader (literal "."))
		     (literal
		      (string-append
		       (format-number
			(ancestor-child-number "SLIDEMODULE") "A")
		       "-"))
		     (current-node-page-number-sosofo))))

(element SLIDE
  (make display-group
	break-before: 'page))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; paragraphs
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(element TITLE
  (make display-group
	space-after: (* %bf-size% %title-size-factor%)
	font-size: (* %bf-size% %title-size-factor%)
	line-spacing: (* %bf-size%  %title-size-factor% 
	                  %line-spacing-factor%)))

(element SUBTITLE
  (make display-group
	space-before: (* %bf-size% %subtitle-size-factor%)
	space-after: (* %bf-size% %subtitle-size-factor%)
	font-size: (* %bf-size% %subtitle-size-factor%)
	line-spacing: (* %bf-size%  %subtitle-size-factor% 
	                  %line-spacing-factor%)))

(element LINE
  (make paragraph))

(element SLIDEHEAD
  (make paragraph
	space-after: (* %bf-size% %slidehead-size-factor%)
	font-size: (* %bf-size% %slidehead-size-factor%)
	line-spacing: (* %bf-size%  %slidehead-size-factor% 
	                  %line-spacing-factor%)))

(element P
  (make paragraph
	space-before: %bf-size%
	space-after: %bf-size%))

(element CODESAMPLE
  (make paragraph
	lines: 'asis
	input-whitespace-treatment: 'preserve
	quadding: 'start
	font-family-name: %mono-font-family%
	font-weight: 'bold
	font-size: (* %bf-size% 0.6)
	line-spacing: (* %bf-size% 0.6)
	space-before: %bf-size%
	space-after: %bf-size%))

(element CONNECTOR
  (make paragraph
	space-before: %bf-size%
	space-after: %bf-size%
	start-indent: (* %bf-size% 3)
	quadding: 'start))


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; lists
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(define %itemstep% %bf-size%)

(define ($list$)
  (make display-group
	space-before: %bf-size%
	space-after: %bf-size%))

(element BULLETLIST ($list$))
(element NUMBEREDLIST ($list$))
(element FLATLIST ($list$))

(element ITEM
  (make display-group
	start-indent: (+ (inherited-start-indent) %itemstep%)))

(element (FLATLIST ITEM P)
  (make paragraph))

(element (NUMBEREDLIST ITEM P)
  (if (= (child-number) 1)
      (make paragraph
	    space-before: (/ %bf-size% 4)
	    space-after: (/ %bf-size% 4)
	    first-line-start-indent: (- %itemstep%)
	    (make line-field
		  field-width: %itemstep%
		  (literal
		   (string-append
		    (format-number (ancestor-child-number "ITEM")
				   "1") ".")))
	    (process-children))
    (make paragraph
	    space-before: (/ %bf-size% 4)
	    space-after: (/ %bf-size% 4))))

(element (BULLETLIST ITEM P)
  (if (= (child-number) 1)
      (make paragraph
	    space-before: (/ %bf-size% 4)
	    space-after: (/ %bf-size% 4)
	    first-line-start-indent: (- %itemstep%)
	    (make line-field
		  font-family-name: "Wingdings"
		  font-size: (* %bf-size% 0.75)
		  field-width: %itemstep%
		  (literal "l"))
	    (process-children))
    (make paragraph
	    space-before: (/ %bf-size% 4)
	    space-after: (/ %bf-size% 4))))

(element BULLETSUBLIST
  (make display-group
	space-before: (/ %bf-size% 4)
	space-after: (/ %bf-size% 4)
	start-indent: (+ (inherited-start-indent) %itemstep%)))

(element (BULLETSUBLIST ITEM P)
  (if (= (child-number) 1)
      (make paragraph
	    space-before: (/ %bf-size% 4)
	    space-after: (/ %bf-size% 4)
	    first-line-start-indent: (- %itemstep%)
	    (make line-field
		  font-family-name: "Wingdings"
		  font-size: (* %bf-size% 0.6)
		  field-width: %itemstep%
		  (literal "o"))
	    (process-children))
    (make paragraph
	    space-before: (/ %bf-size% 4)
	    space-after: (/ %bf-size% 4))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; inlines
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(element B
  (make sequence
	font-weight: 'bold))

(element I
  (make sequence
	font-posture: 'italic))

(define ($ss-seq$ plus-or-minus)
  (make sequence
	font-size:
	  (* (inherited-font-size) %ss-size-factor%)
	position-point-shift:
	  (plus-or-minus (* (inherited-font-size) %ss-shift-factor%))))

(element SUP ($ss-seq$ +))
(element SUB ($ss-seq$ -))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; graphics
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(element IMG
  (make external-graphic
	entity-system-id: (attribute-string "src")
	display?: #t
	space-before: 1pica
	space-after: 1pica
	display-alignment:
	  (case (attribute-string "align")
		(("LEFT") 'start)
		(("RIGHT") 'end)
		(else 'center))))
